# The Allen SDK

[![Join the chat at https://gitter.im/AllenInstitute/AllenSDK](https://badges.gitter.im/AllenInstitute/AllenSDK.svg)](https://gitter.im/AllenInstitute/AllenSDK?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

This repository contains code for processing and analyzing data
in the [Allen Brain Atlas](http://brain-map.org/).

Please visit http://alleninstitute.github.io/AllenSDK for more information.

# Authors

Tim Fliss @tfliss

David Feng @dyf

@jennan

Michael Buice @mabuice

Nicholas Cain @nicain

Florian Franzen @FlorianFranzen

Werner Van Geit @wvangeit

Richard Gerkin @rgerkin

Nathan Gouwens @gouwens

Nile Graddis

Gabe Ocker

Corinne Teeter

Shreejoy Tripathy @stripathy

Saskia de Vries @saskiad

Derric Williams @derricw

Jed Perkins @jfperkins
